==> prefect-2.0b16-py3-none-any.whl: prefect/orion/models/logs.py <==
"""
Functions for interacting with log ORM objects.
Intended for internal use by the Orion API.
"""
from typing import List

import sqlalchemy as sa
from sqlalchemy import select

import prefect.orion.schemas as schemas
from prefect.orion.database.dependencies import inject_db
from prefect.orion.database.interface import OrionDBInterface


@inject_db
async def create_logs(
    session: sa.orm.Session, db: OrionDBInterface, logs: List[schemas.core.Log]
):
    """
    Creates new logs.

    Args:
        session: a database session
        logs: a list of log schemas

    Returns:
        None
    """
    insert_stmt = (await db.insert(db.Log)).values([log.dict() for log in logs])
    await session.execute(insert_stmt)


@inject_db
async def read_logs(
    session: sa.orm.Session,
    db: OrionDBInterface,
    log_filter: schemas.filters.LogFilter,
    offset: int = None,
    limit: int = None,
    sort: schemas.sorting.LogSort = schemas.sorting.LogSort.TIMESTAMP_ASC,
):
    """
    Read logs.

    Args:
        session: a database session
        db: the database interface
        log_filter: only select logs that match these filters
        offset: Query offset
        limit: Query limit
        sort: Query sort

    Returns:
        List[db.Log]: the matching logs
    """
    query = select(db.Log).order_by(sort.as_sql_sort(db)).offset(offset).limit(limit)

    if log_filter:
        query = query.where(log_filter.as_sql_filter(db))

    result = await session.execute(query)
    return result.scalars().unique().all()

==> prefect-2.3.1-py3-none-any.whl: prefect/orion/models/logs.py <==
"""
Functions for interacting with log ORM objects.
Intended for internal use by the Orion API.
"""
from typing import List

import sqlalchemy as sa
from sqlalchemy import select

import prefect.orion.schemas as schemas
from prefect.orion.database.dependencies import inject_db
from prefect.orion.database.interface import OrionDBInterface
from prefect.utilities.collections import batched_iterable

# We have a limit of 32,767 parameters at a time for a single query...
MAXIMUM_QUERY_PARAMETERS = 32_767

# ...and logs have a certain number of fields...
NUMBER_OF_LOG_FIELDS = len(schemas.core.Log.schema()["properties"])

# ...so we can only INSERT batches of a certain size at a time
LOG_BATCH_SIZE = MAXIMUM_QUERY_PARAMETERS // NUMBER_OF_LOG_FIELDS


@inject_db
async def create_logs(
    session: sa.orm.Session, db: OrionDBInterface, logs: List[schemas.core.Log]
):
    """
    Creates new logs.

    Args:
        session: a database session
        logs: a list of log schemas

    Returns:
        None
    """
    log_insert = await db.insert(db.Log)
    for batch in batched_iterable(logs, LOG_BATCH_SIZE):
        await session.execute(log_insert.values([log.dict() for log in batch]))


@inject_db
async def read_logs(
    session: sa.orm.Session,
    db: OrionDBInterface,
    log_filter: schemas.filters.LogFilter,
    offset: int = None,
    limit: int = None,
    sort: schemas.sorting.LogSort = schemas.sorting.LogSort.TIMESTAMP_ASC,
):
    """
    Read logs.

    Args:
        session: a database session
        db: the database interface
        log_filter: only select logs that match these filters
        offset: Query offset
        limit: Query limit
        sort: Query sort

    Returns:
        List[db.Log]: the matching logs
    """
    query = select(db.Log).order_by(sort.as_sql_sort(db)).offset(offset).limit(limit)

    if log_filter:
        query = query.where(log_filter.as_sql_filter(db))

    result = await session.execute(query)
    return result.scalars().unique().all()
